.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.locales`` Ansible role manages localization and
internationalization configuration, used by the ``locales`` Debian package. The
role can be used as a dependency of other Ansible roles to ensure that the
localization is properly configured on the host.
